//
//  IntentViewController.swift
//  SiriDemoIntentUI
//
//  Created by Neil Smyth on 11/13/20.
//

import IntentsUI

// As an example, this extension's Info.plist has been configured to handle interactions for INSendMessageIntent.
// You will want to replace this or add other intents as appropriate.
// The intents whose interactions you wish to handle must be declared in the extension's Info.plist.

// You can test this example integration by saying things to Siri like:
// "Send a message using <myApp>"

class IntentViewController: UIViewController, INUIHostedViewControlling {
    
    @IBOutlet weak var contentLabel: UILabel!
    @IBOutlet var contentView: UIView!
    
    override func viewDidLoad() {
        super.viewDidLoad()
        // Do any additional setup after loading the view.
    }
        
    // MARK: - INUIHostedViewControlling
    
    // Prepare your view controller for the interaction to handle.
    func configureView(for parameters: Set<INParameter>, of interaction: INInteraction, interactiveBehavior: INUIInteractiveBehavior, context: INUIHostedViewContext, completion: @escaping (Bool, Set<INParameter>, CGSize) -> Void) {
        
        var size = CGSize.zero
        
        let content = INParameter(for: INSendMessageIntent.self, keyPath:
            #keyPath(INSendMessageIntent.content))

        let recipients = INParameter(for: INSendMessageIntent.self,
                            keyPath: #keyPath(INSendMessageIntent.recipients))
        
        let recipientsValue = interaction.parameterValue(
               for: recipients) as! Array<INPerson>

        if parameters == [content] {
            let contentValue = interaction.parameterValue(for: content)
            
            self.contentLabel.text = contentValue as? String
            self.contentLabel.textColor = UIColor.white
            self.contentView.backgroundColor = UIColor.brown
            size = CGSize(width: 100, height: 70)
            
        } else if recipientsValue.count > 0 {
            var recipientStr = "To:"
            var first = true
                
            for name in recipientsValue {
                let separator = first ? " " : ", "
                first = false
                recipientStr += separator + name.displayName
            }
                
            self.contentLabel.font = UIFont(name: "Arial-BoldItalicMT", size: 20.0)
            self.contentLabel.text = recipientStr
            self.contentLabel.textColor = UIColor.white
            self.contentView.backgroundColor = UIColor.blue
            size = CGSize(width: 100, height: 30)
                
        } else if parameters.isEmpty {
             completion(false, [], CGSize.zero)
        }
        
        completion(true, parameters, size)
    }
    
    var desiredSize: CGSize {
        return self.extensionContext!.hostedViewMaximumAllowedSize
    }
    
}
