//
//  PhotoHandler.swift
//  SiriPhoto
//
//  Created by Neil Smyth on 11/13/20.
//

import SwiftUI
import Combine
import Intents
import Photos
 
class PhotoHandler: ObservableObject {
    
    @Published var image: UIImage?
    var userActivity: NSUserActivity
    
    init (userActivity: NSUserActivity) {
        
        self.userActivity = userActivity
        self.image = UIImage(named: "image-missing")
        
    }
    
    func handleActivity() {
        
        let intent = userActivity.interaction?.intent
            as! INSearchForPhotosIntent
        
        if (intent.dateCreated?.startDateComponents) != nil {
            let calendar = Calendar(identifier: .gregorian)
            let startDate = calendar.date(from:
                (intent.dateCreated?.startDateComponents)!)
            let endDate = calendar.date(from:
                (intent.dateCreated?.endDateComponents)!)
            getPhoto(startDate!, endDate!)
        }
    }
    
    func getPhoto(_ startDate: Date, _ endDate: Date){
        
        let fetchOptions = PHFetchOptions()
        
        fetchOptions.predicate = NSPredicate(
             format: "creationDate > %@ AND creationDate < %@",
                      startDate as CVarArg, endDate as CVarArg)
        let fetchResult = PHAsset.fetchAssets(with:
            PHAssetMediaType.image, options: fetchOptions)
        
        let imgManager = PHImageManager.default()
        
        if let firstObject = fetchResult.firstObject {
            imgManager.requestImage(for: firstObject as PHAsset,
                                    targetSize: CGSize(width: 500,
                                                        height: 500),
                                    contentMode:
                                         PHImageContentMode.aspectFill,
                                    options: nil,
                                    resultHandler: { (image, _) in
                                        self.image = image
            })
        }
    }

}
