//
//  IntentHandler.swift
//  SiriPhotoIntent
//
//  Created by Neil Smyth on 11/13/20.
//

import Intents
import Photos

class IntentHandler: INExtension, INSearchForPhotosIntentHandling {
    
    override func handler(for intent: INIntent) -> Any {
        // This is the default implementation.  If you want different objects to handle different intents,
        // you can override this and return the handler you want for that particular intent.
        
        return self
    }

    func handle(intent: INSearchForPhotosIntent, completion: @escaping
        (INSearchForPhotosIntentResponse) -> Void) {
        
        let activityType = "com.ebookfrenzy.siriphotointent"
        let activity = NSUserActivity(activityType: activityType)
        
        let response = INSearchForPhotosIntentResponse(code:
            INSearchForPhotosIntentResponseCode.continueInApp,
                                                 userActivity: activity)
        
        if intent.dateCreated != nil {
            let calendar = Calendar(identifier: .gregorian)
            
            if let startComponents = intent.dateCreated?.startDateComponents,
                let endComponents = intent.dateCreated?.endDateComponents {
                
                if let startDate = calendar.date(from:
                    startComponents),
                    let endDate = calendar.date(from:
                        endComponents) {
                    
                    response.searchResultsCount =
                       photoSearchFrom(startDate, to: endDate)
                }
            }
        }
        completion(response)
    }
    
    func photoSearchFrom(_ startDate: Date, to endDate: Date) -> Int {

        let fetchOptions = PHFetchOptions()

        fetchOptions.predicate = NSPredicate(format: "creationDate > %@ AND creationDate < %@", startDate as CVarArg, endDate as CVarArg)
        let fetchResult = PHAsset.fetchAssets(with: PHAssetMediaType.image,
                options: fetchOptions)
        return fetchResult.count
    }
    
    func resolveDateCreated(for
        intent: INSearchForPhotosIntent,
        with completion: @escaping
            (INDateComponentsRangeResolutionResult) -> Void) {

        if let dateCreated = intent.dateCreated {
            completion(INDateComponentsRangeResolutionResult.success(
                with: dateCreated))
        } else {
            completion(INDateComponentsRangeResolutionResult.needsValue())
        }
    }
    
    func resolveAlbumName(for intent: INSearchForPhotosIntent,
        with completion: @escaping (INStringResolutionResult) -> Void) {
        completion(INStringResolutionResult.notRequired())
    }

    func resolvePeopleInPhoto(for intent:
         INSearchForPhotosIntent, with completion: @escaping ([INPersonResolutionResult]) -> Void) {
        completion([INPersonResolutionResult.notRequired()])
    }

    func resolveLocationCreated(for intent:
        INSearchForPhotosIntent, with completion: @escaping (INPlacemarkResolutionResult) -> Void) {
            completion(INPlacemarkResolutionResult.notRequired())
    }
    
    func confirm(intent: INSearchForPhotosIntent,
        completion: @escaping (INSearchForPhotosIntentResponse) -> Void)
    {
        let response = INSearchForPhotosIntentResponse(code: .ready,
            userActivity: nil)
        completion(response)
    }
}
